@@ -13,7 +13,7 @@ import PIL.Image
 import requests
 
 from pyxllib.prog.newbie import round_int, RunOnlyOnce
-from pyxllib.prog.pupil import EnchantBase
+from pyxllib.prog.pupil import EnchantBase, EnchantCvt
 from pyxllib.algo.geo import rect_bounds, warp_points, reshape_coords, quad_warp_wh, get_warp_mat, rect2polygon
 from pyxllib.file.specialist import File
 
@@ -30,8 +30,8 @@ class xlcv(EnchantBase):
         不太推荐使用该类，可以使用CvImg类更好地解决问题。
         """
         # 虽然只绑定cv2，但其他相关的几个库的方法上，最好也不要重名
-        cls.check_enchant_names([np.ndarray, PIL.Image, PIL.Image.Image])
-        cls._enchant(cv2, 'staticmethod2modulefunc')
+        names = cls.check_enchant_names([np.ndarray, PIL.Image, PIL.Image.Image])
+        cls._enchant(cv2, names, EnchantCvt.staticmethod2modulefunc)
 
     @staticmethod
     def __1_read():
@@ -541,10 +541,9 @@ class xlcv(EnchantBase):
             同理，其他点数量，默认为
         :param fill: 支持pts越界选取，此时可以设置fill自动填充的颜色值
             TODO fill填充一个rgb颜色的时候应该会不兼容报错，还要想办法优化
-        :param warp_quad: 变形的四边形
-            默认是截图pts的外接四边形区域，使用该参数
-                且当pts为四个点时，是否强行扭转为矩形
-            一般写 'average'，也可以写'max'、'min'，详见 quad_warp_wh()
+        :param warp_quad: 当pts为四个点时，是否进行仿射变换矫正
+            默认是截图pts的外接四边形区域
+            一般写 True、'average'，也可以写'max'、'min'，详见 quad_warp_wh()
         :return: 子图
             文件、np.ndarray --> np.ndarray
             PIL.Image --> PIL.Image
