@@ -4,38 +4,28 @@
 # @Email  : 877362867@qq.com
 # @Date   : 2020/06/06
 
+from pyxllib.prog.pupil import check_install_package
+
+check_install_package('pyautogui')
+check_install_package('keyboard')
+
 from collections import defaultdict
 import json
 import os
-import subprocess
-import sys
 import time
 
-try:
-    import pyautogui
-except ModuleNotFoundError:
-    subprocess.run(['pip3', 'install', 'pyautogui'])
-    import pyautogui
-
-try:
-    import keyboard
-except ModuleNotFoundError:
-    subprocess.run(['pip3', 'install', 'keyboard'])
-    import keyboard
-
-import pyscreeze  # NOQA pyautogui安装的时候会自动安装依赖的pyscreeze
-import imagehash
-
 import numpy as np
 from pandas.api.types import is_list_like
+import pyautogui
+import pyscreeze  # NOQA pyautogui安装的时候会自动安装依赖的pyscreeze
 
-from pyxllib.debug.specialist import TicToc
-from pyxllib.file.specialist import File, Dir, get_etag
 from pyxllib.prog.newbie import first_nonnone, round_int
-from pyxllib.prog.pupil import xlwait, DictTool
-from pyxllib.cv.expert import xlcv, xlpil
+from pyxllib.prog.pupil import xlwait, DictTool, check_install_package
 from pyxllib.algo.geo import ComputeIou, ltrb2xywh, xywh2ltrb
 from pyxllib.algo.shapely_ import ShapelyPolygon
+from pyxllib.file.specialist import File, Dir
+from pyxllib.debug.specialist import TicToc
+from pyxllib.cv.expert import xlcv, xlpil
 from pyxllib.data.labelme import LabelmeDict
 
 
@@ -560,6 +550,63 @@ def lookup_mouse_position2(w1, w2, reverse=False):
         time.sleep(0.4)
 
 
+def type_text(text):
+    """ 打印出文本内容
+
+    相比pyautogui.write，这里支持中文等unicode格式
+
+    这种需求一般也可以用剪切板实现，是剪切板不够静默、quit
+    """
+    check_install_package('pynput')
+    from pynput.keyboard import Controller
+
+    keyboard = Controller()
+    keyboard.type(text)
+
+
+def clipboard_decorator(rtype='text', *, copy=True, paste=False, typing=False):
+    """ 装饰器，能方便地将函数的返回值转移到剪切板文本、富文本，甚至typing出来。
+
+    Args:
+        rtype: 函数返回值类型
+        paste: 是否执行剪切板的粘贴功能
+        typing: 是否键入文本内容
+
+    Returns:
+
+    """
+    from bs4 import BeautifulSoup
+    import pyautogui
+    import klembord
+
+    def decorator(func):
+        def wrapper(*args, **kwargs):
+            # 1 运行函数获得结果
+            s = func(*args, **kwargs)
+
+            # 2 复制到剪切板
+            if copy:
+                if rtype == 'text' and isinstance(s, str):
+                    klembord.set_text(s)
+                elif rtype == 'html' and isinstance(s, str):
+                    s0 = BeautifulSoup(s, 'lxml').text
+                    klembord.set_with_rich_text(s0, s)
+                elif rtype == 'dict' and isinstance(s, dict):
+                    klembord.set(s)
+
+            # 3 输出
+            if paste:
+                pyautogui.hotkey('ctrl', 'v')  # 目前来看就这个方法最靠谱
+            if typing:
+                type_text(s)
+
+            return s
+
+        return wrapper
+
+    return decorator
+
+
 if __name__ == '__main__':
     with TicToc(__name__):
         agld = AutoGuiLabelData(r'D:\slns\py4101\py4101\touhou\label')
